@@ -21,7 +21,8 @@ import sys
 
 from keystoneclient.v2_0 import client as ksclient
 
-from heatclient import client as heatclient
+import heatclient
+from heatclient import client as heat_client
 from heatclient.common import utils
 from heatclient import exc
 
@@ -45,6 +46,11 @@ class HeatShell(object):
                             action='store_true',
                             help=argparse.SUPPRESS)
 
+        parser.add_argument('--version',
+                            action='version',
+                            version=heatclient.__version__,
+                            help="Shows the client version and exits")
+
         parser.add_argument('-d', '--debug',
                             default=bool(utils.env('HEATCLIENT_DEBUG')),
                             action='store_true',
@@ -169,7 +175,7 @@ class HeatShell(object):
         parser.add_argument('-t', '--token-only',
                             default=bool(False),
                             action='store_true',
-                            help='DEPRECATED! Has no effect')
+                            help=argparse.SUPPRESS)
 
         return parser
 
@@ -224,6 +230,12 @@ class HeatShell(object):
 
     def _get_endpoint(self, client, **kwargs):
         """Get an endpoint using the provided keystone client."""
+        if kwargs.get('region_name'):
+            return client.service_catalog.url_for(
+                service_type=kwargs.get('service_type') or 'orchestration',
+                attr='region',
+                filter_value=kwargs.get('region_name'),
+                endpoint_type=kwargs.get('endpoint_type') or 'publicURL')
         return client.service_catalog.url_for(
             service_type=kwargs.get('service_type') or 'orchestration',
             endpoint_type=kwargs.get('endpoint_type') or 'publicURL')
@@ -236,11 +248,16 @@ class HeatShell(object):
 
             httplib2.debuglevel = 1
 
+    def _setup_verbose(self, verbose):
+        if verbose:
+            exc.verbose = 1
+
     def main(self, argv):
         # Parse args once to find version
         parser = self.get_base_parser()
         (options, args) = parser.parse_known_args(argv)
         self._setup_debugging(options.debug)
+        self._setup_verbose(options.verbose)
 
         # build available subcommands based on version
         api_version = options.heat_api_version
@@ -278,6 +295,11 @@ class HeatShell(object):
             raise exc.CommandError("You must provide an auth url via"
                                    " either --os-auth-url or via "
                                    "env[OS_AUTH_URL]")
+        if args.os_no_client_auth and not args.heat_url:
+            raise exc.CommandError("If you specify --os-no-client-auth"
+                                   " you must also specify a Heat API URL "
+                                   "via either --heat-url or "
+                                   "env[HEAT_URL]")
         kwargs = {
             'username': args.os_username,
             'password': args.os_password,
@@ -306,15 +328,15 @@ class HeatShell(object):
                 'password': args.os_password
             }
 
+            if args.os_region_name:
+                kwargs['region_name'] = args.os_region_name
+
             if not endpoint:
                 endpoint = self._get_endpoint(_ksclient, **kwargs)
 
-        client = heatclient.Client(api_version, endpoint, **kwargs)
+        client = heat_client.Client(api_version, endpoint, **kwargs)
 
-        try:
-            args.func(client, args)
-        except exc.Unauthorized:
-            raise exc.CommandError("Invalid OpenStack Identity credentials.")
+        args.func(client, args)
 
     @utils.arg('command', metavar='<subcommand>', nargs='?',
                help='Display help for <subcommand>')
