@@ -1,4 +1,4 @@
-# Copyright 2012 OpenStack LLC.
+# Copyright 2012 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -103,7 +103,10 @@ def _process_environment_and_files(hc, args, fields):
 @utils.arg('-r', '--enable-rollback', default=False, action="store_true",
            help='Enable rollback on create/update failure')
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
-           help='Parameter values used to create the stack.')
+           help='Parameter values used to create the stack. '
+           'This can be specified multiple times, or once with parameters '
+           'separated by semicolon.',
+           action='append')
 @utils.arg('name', metavar='<STACK_NAME>',
            help='Name of the stack to create.')
 def do_create(hc, args):
@@ -125,7 +128,10 @@ def do_create(hc, args):
 @utils.arg('-r', '--enable-rollback', default=False, action="store_true",
            help='Enable rollback on create/update failure')
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
-           help='Parameter values used to create the stack.')
+           help='Parameter values used to create the stack. '
+           'This can be specified multiple times, or once with parameters '
+           'separated by semicolon.',
+           action='append')
 @utils.arg('name', metavar='<STACK_NAME>',
            help='Name of the stack to create.')
 def do_stack_create(hc, args):
@@ -221,7 +227,10 @@ def do_stack_show(hc, args):
 @utils.arg('-o', '--template-object', metavar='<URL>',
            help='URL to retrieve template object (e.g from swift)')
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
-           help='Parameter values used to create the stack.')
+           help='Parameter values used to create the stack. '
+           'This can be specified multiple times, or once with parameters '
+           'separated by semicolon.',
+           action='append')
 @utils.arg('id', metavar='<NAME or ID>',
            help='Name or ID of stack to update.')
 def do_update(hc, args):
@@ -238,7 +247,10 @@ def do_update(hc, args):
 @utils.arg('-o', '--template-object', metavar='<URL>',
            help='URL to retrieve template object (e.g from swift)')
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
-           help='Parameter values used to create the stack.')
+           help='Parameter values used to create the stack. '
+           'This can be specified multiple times, or once with parameters '
+           'separated by semicolon.',
+           action='append')
 @utils.arg('id', metavar='<NAME or ID>',
            help='Name or ID of stack to update.')
 def do_stack_update(hc, args):
@@ -297,7 +309,10 @@ def do_template_show(hc, args):
 @utils.arg('-o', '--template-object', metavar='<URL>',
            help='URL to retrieve template object (e.g from swift)')
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
-           help='Parameter values to validate.')
+           help='Parameter values to validate. '
+           'This can be specified multiple times, or once with parameters '
+           'separated by semicolon.',
+           action='append')
 def do_validate(hc, args):
     '''DEPRECATED! Use template-validate instead.'''
     do_template_validate(hc, args)
@@ -312,7 +327,10 @@ def do_validate(hc, args):
 @utils.arg('-o', '--template-object', metavar='<URL>',
            help='URL to retrieve template object (e.g from swift)')
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
-           help='Parameter values to validate.')
+           help='Parameter values to validate. '
+           'This can be specified multiple times, or once with parameters '
+           'separated by semicolon.',
+           action='append')
 def do_template_validate(hc, args):
     '''Validate a template with parameters.'''
     fields = {'parameters': utils.format_parameters(args.parameters)}
@@ -333,8 +351,13 @@ def do_resource_list(hc, args):
     except exc.HTTPNotFound:
         raise exc.CommandError('Stack not found: %s' % args.id)
     else:
-        fields = ['logical_resource_id', 'resource_type',
-                  'resource_status', 'updated_time']
+        fields = ['resource_type', 'resource_status', 'updated_time']
+        if len(resources) >= 1:
+            if hasattr(resources[0], 'resource_name'):
+                fields.insert(0, 'resource_name')
+            else:
+                fields.insert(0, 'logical_resource_id')
+
         utils.print_list(resources, fields, sortby=3)
 
 
@@ -368,6 +391,24 @@ def do_resource_show(hc, args):
         utils.print_dict(resource.to_dict(), formatters=formatters)
 
 
+@utils.arg('resource', metavar='<RESOURCE>',
+           help='Name of the resource to generate a template for.')
+@utils.arg('-F', '--format', metavar='<FORMAT>',
+           help="The template output format. %s" % utils.supported_formats)
+def do_resource_template(hc, args):
+    '''Generate a template based on a resource.'''
+    fields = {'resource_name': args.resource}
+    try:
+        template = hc.resources.generate_template(**fields)
+    except exc.HTTPNotFound:
+        raise exc.CommandError('Resource %s not found.' % args.resource)
+    else:
+        if args.format:
+            print utils.format_output(template, format=args.format)
+        else:
+            print utils.format_output(template)
+
+
 @utils.arg('id', metavar='<NAME or ID>',
            help='Name or ID of stack to show the resource metadata for.')
 @utils.arg('resource', metavar='<RESOURCE>',
@@ -398,9 +439,14 @@ def do_event_list(hc, args):
     except exc.HTTPNotFound:
         raise exc.CommandError('Stack not found: %s' % args.id)
     else:
-        fields = ['logical_resource_id', 'id', 'resource_status_reason',
+        fields = ['id', 'resource_status_reason',
                   'resource_status', 'event_time']
-        utils.print_list(events, fields, sortby=4)
+        if len(events) >= 1:
+            if hasattr(events[0], 'resource_name'):
+                fields.insert(0, 'resource_name')
+            else:
+                fields.insert(0, 'logical_resource_id')
+        utils.print_list(events, fields)
 
 
 @utils.arg('id', metavar='<NAME or ID>',
